@@ -33,10 +33,10 @@
 #include <string>
 #include <vector>
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 #include <agrum/core/list.h>
 
-#include <agrum/multidim/multiDimSparse.h>
+#include <agrum/multidim/implementations/multiDimSparse.h>
 #include <agrum/variables/discreteVariable.h>
 
 #include <agrum/PRM/IPRMFactory.h>
@@ -68,7 +68,7 @@ namespace gum {
      * @ingroup prm_group
      */
     // ==========================================================================
-    template <typename GUM_SCALAR>
+    template < typename GUM_SCALAR >
     class PRMFactory : public IPRMFactory {
       public:
       // ======================================================================
@@ -84,13 +84,13 @@ namespace gum {
       /**
        * This constructor let you set on which PRM instance the factory works.
        */
-      PRMFactory( PRM<GUM_SCALAR>* prm );
+      PRMFactory(PRM< GUM_SCALAR >* prm);
 
       /// Copy constructor. Don't use it.
-      PRMFactory( const PRMFactory& from ) = delete;
+      PRMFactory(const PRMFactory& from) = delete;
 
       /// Copy operator. Don't use it.
-      PRMFactory& operator=( const PRMFactory& from ) = delete;
+      PRMFactory& operator=(const PRMFactory& from) = delete;
       /**
        * Destructor.
        */
@@ -108,7 +108,7 @@ namespace gum {
        *
        * @return Returns the PRM<GUM_SCALAR> created by this factory.
        */
-      PRM<GUM_SCALAR>* prm() const;
+      PRM< GUM_SCALAR >* prm() const;
 
       /**
        * @return Returns the PRMObject type of the object begin built.
@@ -149,7 +149,7 @@ namespace gum {
        * @return the Class<GUM_SCALAR> with the given name.
        * @throw NotFound if no Class<GUM_SCALAR> matches the given name.
        */
-      PRMClass<GUM_SCALAR>& retrieveClass( const std::string& name );
+      PRMClass< GUM_SCALAR >& retrieveClass(const std::string& name);
 
       /**
        * @brief Returns a reference over a PRMType<GUM_SCALAR> given its name.
@@ -159,7 +159,7 @@ namespace gum {
        * @return the PRMType<GUM_SCALAR> with the given name.
        * @throw NotFound if no PRMType<GUM_SCALAR> matches the given name.
        */
-      PRMType<GUM_SCALAR>& retrieveType( const std::string& name );
+      PRMType< GUM_SCALAR >& retrieveType(const std::string& name);
 
 
       /* @brief Retrieve the common PRMType<GUM_SCALAR> of a vector of
@@ -186,8 +186,8 @@ namespace gum {
        * @throw NotFound Raised if there exists no common super type of all
        *                 PRMClassElement<GUM_SCALAR> in elts.
        */
-      PRMType<GUM_SCALAR>&
-      retrieveCommonType( const std::vector<PRMClassElement<GUM_SCALAR>*>& elts );
+      PRMType< GUM_SCALAR >& retrieveCommonType(
+        const std::vector< PRMClassElement< GUM_SCALAR >* >& elts);
 
       ///@}
       // ======================================================================
@@ -203,7 +203,7 @@ namespace gum {
        *
        * @param name The name of the package for all further objects.
        */
-      virtual void pushPackage( const std::string& name ) override;
+      virtual void pushPackage(const std::string& name) override;
 
       /**
        * @brief Pop the current package from the package stack.
@@ -231,7 +231,7 @@ namespace gum {
        *
        * @param name The name of the package for all further objects.
        */
-      virtual void addImport( const std::string& name ) override;
+      virtual void addImport(const std::string& name) override;
 
       /// @}
       // ======================================================================
@@ -248,8 +248,8 @@ namespace gum {
        * @throw DuplicateElement Raised if an object with the same name
        *                         already exists.
        */
-      virtual void startDiscreteType( const std::string& name,
-                                      std::string        super = "" ) override;
+      virtual void startDiscreteType(const std::string& name,
+                                     std::string        super = "") override;
 
       /**
        * Add a label to the current discrete type.
@@ -264,7 +264,7 @@ namespace gum {
        * @throw NotFound Raised if ext does not match any label in the
        * current type's super type.
        */
-      virtual void addLabel( const std::string& l, std::string ext = "" ) override;
+      virtual void addLabel(const std::string& l, std::string ext = "") override;
 
       /**
        * End the current discrete type declaration.
@@ -273,14 +273,52 @@ namespace gum {
        *                            discrete type.
        */
       virtual void endDiscreteType() override;
-      /// @}
 
+      /**
+       * Start a discretized type declaration.
+       *
+       * @param name The discretized type's name.
+       *
+       * @throw DuplicateElement Raised if an object with the same name
+       *                         already exists.
+       */
+      virtual void startDiscretizedType(const std::string& name) override;
+
+      /**
+       * Add a tick to the current discretized type.
+       *
+       * @param tick The tick value.
+       */
+      virtual void addTick(double tick) override;
+
+      /**
+       * End the current discretized type declaration.
+       *
+       * @throw OperationNotAllowed Raised if the current type is not a valid
+       *                            discrete type.
+       */
+      virtual void endDiscretizedType() override;
+
+      /**
+       * Add a range variable type declaration.
+       *
+       * @param name The variable's name
+       * @param minVal The variable's lower bound.
+       * @param maxVal The variable's upper bound.
+       *
+       * @throw DuplicateElement Raised if an object with the same name
+       *                         already exists.
+       * @throw OperationNotAllowed Raised if the range variable is not a valid
+       * discrete type.
+       */
+      virtual void
+        addRangeType(const std::string& name, long minVal, long maxVal) override;
+      /// @}
 
       ///@name several checks for parsers
       /// @{
-      virtual bool isClassOrInterface( const std::string& type ) const override;
-      virtual bool
-      isArrayInCurrentSystem( const std::string& name ) const override;
+      virtual bool isClassOrInterface(const std::string& type) const override;
+      virtual bool isArrayInCurrentSystem(const std::string& name) const override;
       /// @}
 
 
@@ -301,15 +339,15 @@ namespace gum {
        *
        * @throw OperationNotAllowed Raised if the given operation is illegal.
        */
-      virtual void startClass( const std::string&      c,
-                               const std::string&      ext = "",
-                               const Set<std::string>* implements = nullptr,
-                               bool delayInheritance = false ) override;
+      virtual void startClass(const std::string&        c,
+                              const std::string&        ext = "",
+                              const Set< std::string >* implements = nullptr,
+                              bool delayInheritance = false) override;
 
       /**
        * Continue the declaration of a class.
        */
-      virtual void continueClass( const std::string& c ) override;
+      virtual void continueClass(const std::string& c) override;
 
       /**
        * Tells the factory that we finished a class declaration.
@@ -318,7 +356,7 @@ namespace gum {
        *respect one of
        *                  it's PRMInterface<GUM_SCALAR>.
        */
-      virtual void endClass( bool checkImplementations = true ) override;
+      virtual void endClass(bool checkImplementations = true) override;
 
       /// @}
       // ======================================================================
@@ -340,21 +378,21 @@ namespace gum {
        * @throw NotFound Raised if ext does not match any declared
        *                 PRMInterface<GUM_SCALAR>.
        */
-      virtual void startInterface( const std::string& i,
-                                   const std::string& ext = "",
-                                   bool delayInheritance = false ) override;
+      virtual void startInterface(const std::string& i,
+                                  const std::string& ext = "",
+                                  bool delayInheritance = false) override;
 
       /**
        * Continue the declaration of an interface.
        */
-      virtual void continueInterface( const std::string& name ) override;
+      virtual void continueInterface(const std::string& name) override;
 
       /**
        * @brief Add an attribute to an interface.
        *
        */
-      virtual void addAttribute( const std::string& type,
-                                 const std::string& name ) override;
+      virtual void addAttribute(const std::string& type,
+                                const std::string& name) override;
 
       /**
        * Tells the factory that we finished an interface declaration.
@@ -387,20 +425,20 @@ namespace gum {
        * @throw NotFound Raised if one of the DiscreteVariable in attr CPT does
        *                 not match any PRMClassElement<GUM_SCALAR> in this.
        */
-      virtual void addAttribute( PRMAttribute<GUM_SCALAR>* attr );
+      virtual void addAttribute(PRMAttribute< GUM_SCALAR >* attr);
 
       /**
        * Tells the factory that we start an attribute declaration.
        * @throw FatalError Raised if the given operation is illegal.
        */
-      virtual void startAttribute( const std::string& type,
-                                   const std::string& name,
-                                   bool scalar_atttr = false ) override;
+      virtual void startAttribute(const std::string& type,
+                                  const std::string& name,
+                                  bool scalar_atttr = false) override;
 
       /**
        * Continues the declaration of an attribute.
        */
-      virtual void continueAttribute( const std::string& name ) override;
+      virtual void continueAttribute(const std::string& name) override;
 
       /**
        * Tells the factory that we add a parent to the current declared
@@ -410,7 +448,7 @@ namespace gum {
        * reference in it.
        * @throw OperationNotAllowed Raised if the given operation is illegal.
        */
-      virtual void addParent( const std::string& name ) override;
+      virtual void addParent(const std::string& name) override;
 
       /**
        * Gives the factory the CPF in its raw form.
@@ -431,7 +469,7 @@ namespace gum {
        *
        * @throw OperationNotAllowed Raised if the given operation is illegal.
        */
-      void setRawCPFByLines( const std::vector<GUM_SCALAR>& array );
+      void setRawCPFByLines(const std::vector< GUM_SCALAR >& array);
 
       /**
        * @brief  Gives the factory the CPF in its raw form.
@@ -453,7 +491,7 @@ namespace gum {
        *
        * @throw OperationNotAllowed Raised if the given operation is illegal.
        */
-      void setRawCPFByColumns( const std::vector<GUM_SCALAR>& array );
+      void setRawCPFByColumns(const std::vector< GUM_SCALAR >& array);
 
       /**
        * @brief Fills the CPF using a rule.
@@ -467,8 +505,8 @@ namespace gum {
        * @param values The probability values of the current attribute given
        *               the values in parents.
        */
-      virtual void setCPFByRule( const std::vector<std::string>& labels,
-                                 const std::vector<GUM_SCALAR>&  values );
+      virtual void setCPFByRule(const std::vector< std::string >& labels,
+                                const std::vector< GUM_SCALAR >&  values);
 
       /**
        * @brief Fills the CPF using a rule and gum::Formula.
@@ -482,8 +520,8 @@ namespace gum {
        * @param values The probability values of the current attribute given
        *               the values in parents.
        */
-      virtual void setCPFByRule( const std::vector<std::string>& labels,
-                                 const std::vector<std::string>& values ) override;
+      virtual void setCPFByRule(const std::vector< std::string >& labels,
+                                const std::vector< std::string >& values) override;
 
       /**
        * @brief Gives the factory the CPF in its raw form.
@@ -505,7 +543,7 @@ namespace gum {
        * @throw OperationNotAllowed Raised if the given operation is illegal.
        */
       virtual void
-      setRawCPFByFloatLines( const std::vector<float>& array ) override;
+        setRawCPFByFloatLines(const std::vector< float >& array) override;
 
       /**
        * @brief Gives the factory the CPF in its raw form.
@@ -528,7 +566,7 @@ namespace gum {
        * @throw OperationNotAllowed Raised if the given operation is illegal.
        */
       virtual void
-      setRawCPFByFloatColumns( const std::vector<float>& array ) override;
+        setRawCPFByFloatColumns(const std::vector< float >& array) override;
 
       /**
        * @brief  Gives the factory the CPF in its raw form use gum::Formula.
@@ -551,7 +589,7 @@ namespace gum {
        * @throw OperationNotAllowed Raised if the given operation is illegal.
        */
       virtual void
-      setRawCPFByColumns( const std::vector<std::string>& array ) override;
+        setRawCPFByColumns(const std::vector< std::string >& array) override;
 
       /**
        * @brief Gives the factory the CPF in its raw form using gum::Formula.
@@ -573,7 +611,7 @@ namespace gum {
        * @throw OperationNotAllowed Raised if the given operation is illegal.
        */
       virtual void
-      setRawCPFByLines( const std::vector<std::string>& array ) override;
+        setRawCPFByLines(const std::vector< std::string >& array) override;
 
       /**
        * @brief Fills the CPF using a rule.
@@ -587,8 +625,8 @@ namespace gum {
        * @param values The probability values of the current attribute given
        *               the values in parenst.
        */
-      virtual void setCPFByFloatRule( const std::vector<std::string>& labels,
-                                      const std::vector<float>& values ) override;
+      virtual void setCPFByFloatRule(const std::vector< std::string >& labels,
+                                     const std::vector< float >& values) override;
 
       /**
        * Tells the factory that we finished declaring an attribute.
@@ -613,9 +651,9 @@ namespace gum {
        * @param name The name of this parameter.
        * @param value The label used as default value for this parameter.
        */
-      void addParameter( const std::string& type,
-                         const std::string& name,
-                         double             value ) override;
+      void addParameter(const std::string& type,
+                        const std::string& name,
+                        double             value) override;
       /// @}
       // ======================================================================
       /// @name Aggregator and function construction methods.
@@ -644,11 +682,11 @@ namespace gum {
        * @throw WrongType Raised if the aggregator's type or one or more of the
        * chains are not of the good type.
        */
-      virtual void addAggregator( const std::string&              name,
-                                  const std::string&              agg_type,
-                                  const std::vector<std::string>& chains,
-                                  const std::vector<std::string>& params,
-                                  std::string type = "" ) override;
+      virtual void addAggregator(const std::string&                name,
+                                 const std::string&                agg_type,
+                                 const std::vector< std::string >& chains,
+                                 const std::vector< std::string >& params,
+                                 std::string type = "") override;
 
       /**
        * @brief Start an aggregator declaration.
@@ -659,15 +697,15 @@ namespace gum {
        * Aggregate::type()).
        * @param params The aggregator's parameters.
        */
-      void startAggregator( const std::string&              name,
-                            const std::string&              agg_type,
-                            const std::string&              rv_type,
-                            const std::vector<std::string>& params );
+      void startAggregator(const std::string&                name,
+                           const std::string&                agg_type,
+                           const std::string&                rv_type,
+                           const std::vector< std::string >& params);
 
       /**
        * @brief Conitnues an aggregator declaration.
        */
-      void continueAggregator( const std::string& name );
+      void continueAggregator(const std::string& name);
 
 
       /**
@@ -700,11 +738,11 @@ namespace gum {
        *                            invalid.
        */
       virtual void
-      addNoisyOrCompound( const std::string&              name,
-                          const std::vector<std::string>& chains,
-                          const std::vector<float>&       numbers,
-                          float                           leak,
-                          const std::vector<std::string>& label ) override;
+        addNoisyOrCompound(const std::string&                name,
+                           const std::vector< std::string >& chains,
+                           const std::vector< float >&       numbers,
+                           float                             leak,
+                           const std::vector< std::string >& label) override;
       /// @}
       // ======================================================================
       /// @name PRMReferenceSlot<GUM_SCALAR> construction methods.
@@ -715,9 +753,9 @@ namespace gum {
        * Tells the factory that we started declaring a slot.
        * @throw OperationNotAllowed Raised if the given operation is illegal.
        */
-      virtual void addReferenceSlot( const std::string& type,
-                                     const std::string& name,
-                                     bool               isArray ) override;
+      virtual void addReferenceSlot(const std::string& type,
+                                    const std::string& name,
+                                    bool               isArray) override;
 
       /// @}
       // ======================================================================
@@ -729,7 +767,7 @@ namespace gum {
        * Tells the factory that we started declaring a model.
        * @throw OperationNotAllowed Raised if the given operation is illegal.
        */
-      virtual void startSystem( const std::string& name ) override;
+      virtual void startSystem(const std::string& name) override;
 
       /**
        * Tells the factory that we finished declaring a model.
@@ -740,15 +778,15 @@ namespace gum {
       /**
        * Add an instance to the model.
        */
-      virtual void addInstance( const std::string& type,
-                                const std::string& name ) override;
+      virtual void addInstance(const std::string& type,
+                               const std::string& name) override;
 
       /**
        * Add an instance with params as values of type's parameters.
        */
-      void addInstance( const std::string& type,
-                        const std::string& name,
-                        const HashTable<std::string, double>& params ) override;
+      void addInstance(const std::string&                      type,
+                       const std::string&                      name,
+                       const HashTable< std::string, double >& params) override;
 
       /**
        * Creates an array with the given number of instances of the given type.
@@ -756,15 +794,15 @@ namespace gum {
        * suffix "[i]",
        * with "i" being the position of the instance in the array.
        */
-      virtual void addArray( const std::string& type,
-                             const std::string& name,
-                             Size               size ) override;
+      virtual void addArray(const std::string& type,
+                            const std::string& name,
+                            Size               size) override;
 
       /**
        * Add an instance to an array.
        */
-      virtual void incArray( const std::string& l_i,
-                             const std::string& r_i ) override;
+      virtual void incArray(const std::string& l_i,
+                            const std::string& r_i) override;
 
       /**
        * @brief Instantiate a reference in the current model.
@@ -780,9 +818,9 @@ namespace gum {
        * @param right_instance The name of an instance or an array of instances
        *                       in the model.
        */
-      virtual void setReferenceSlot( const std::string& left_instance,
-                                     const std::string& left_reference,
-                                     const std::string& right_instance ) override;
+      virtual void setReferenceSlot(const std::string& left_instance,
+                                    const std::string& left_reference,
+                                    const std::string& right_instance) override;
 
       /**
        * @brief Instantiate a reference in the current model.
@@ -798,15 +836,15 @@ namespace gum {
        * @param r_i The name of an instance or an array of instances in the
        *model.
        */
-      virtual void setReferenceSlot( const std::string& l_i,
-                                     const std::string& r_i ) override;
+      virtual void setReferenceSlot(const std::string& l_i,
+                                    const std::string& r_i) override;
 
       /// @}
 
       private:
       /// Decompose a string in v using dots ('.') as delimiters.
-      void __fill_sc_in_vector( std::vector<std::string>& v,
-                                const std::string&        str );
+      void __fill_sc_in_vector(std::vector< std::string >& v,
+                               const std::string&          str);
 
       // ======================================================================
       ///  @name Private methods for type checking and exception handling.
@@ -814,19 +852,19 @@ namespace gum {
       /// @{
 
       /// Adds __prefix to str iff __prefix != ""
-      std::string __addPrefix( const std::string& str ) const;
+      std::string __addPrefix(const std::string& str) const;
 
       /// Return a pointer on a PRMObject at __stack.size() - i position after
       /// checking the type of the object given obj_type.
       /// @throw FactoryInvalidState Raised if the stack isn't consistent with
       /// the
       //                             current declaration.
-      PRMObject* __checkStack( Idx i, PRMObject::prm_type obj_type );
+      PRMObject* __checkStack(Idx i, PRMObject::prm_type obj_type);
 
-      PRMClassElement<GUM_SCALAR>* __checkStack(
-          Idx i, typename PRMClassElement<GUM_SCALAR>::ClassElementType obj_type );
+      PRMClassElement< GUM_SCALAR >* __checkStack(
+        Idx i, typename PRMClassElement< GUM_SCALAR >::ClassElementType obj_type);
 
-      PRMClassElementContainer<GUM_SCALAR>* __checkStackContainter( Idx i );
+      PRMClassElementContainer< GUM_SCALAR >* __checkStackContainter(Idx i);
 
       /// @}
       // ======================================================================
@@ -850,22 +888,22 @@ namespace gum {
       /// In the case a local name is used multiple time, it's preferable to
       /// use it's full name.
       /// @throw OperationNotAllowed If the type is undeclared.
-      PRMType<GUM_SCALAR>* __retrieveType( const std::string& name ) const;
+      PRMType< GUM_SCALAR >* __retrieveType(const std::string& name) const;
 
       /// Returns a pointer on a class given it's name. Used when building
       /// models, meaning that the class name can either be local (need to
       /// add the current prefix) or global (no prefix needed).
       /// @throw NotFound If no class matching the name is found.
       /// @see PRMFactory::__retrieveType
-      PRMClass<GUM_SCALAR>* __retrieveClass( const std::string& name ) const;
+      PRMClass< GUM_SCALAR >* __retrieveClass(const std::string& name) const;
 
       /// Returns a pointer on an interface given it's name. Used when building
       /// models, meaning that the interface name can either be local (need to
       /// add the current prefix) or global (no prefix needed).
       /// @throw NotFound If no class matching the name is found.
       /// @see PRMFactory::__retrieveType
-      PRMInterface<GUM_SCALAR>*
-      __retrieveInterface( const std::string& name ) const;
+      PRMInterface< GUM_SCALAR >*
+        __retrieveInterface(const std::string& name) const;
 
       /// @}
       // ======================================================================
@@ -880,9 +918,9 @@ namespace gum {
       /// @return Return a pointer over a PRMSlotChain<GUM_SCALAR> or 0 if no
       /// PRMSlotChain<GUM_SCALAR> could be built.
       ///
-      PRMSlotChain<GUM_SCALAR>*
-      __buildSlotChain( PRMClassElementContainer<GUM_SCALAR>* start,
-                        const std::string&                    name );
+      PRMSlotChain< GUM_SCALAR >*
+        __buildSlotChain(PRMClassElementContainer< GUM_SCALAR >* start,
+                         const std::string&                      name);
 
       /// @brief Retrieve inputs for an PRMAggregate.
       ///
@@ -905,9 +943,9 @@ namespace gum {
       /// @throw NotFound Raised if a name in chains does not match a legal
       ///                 PRMSlotChain<GUM_SCALAR> or an existing
       ///                 PRMClassElement<GUM_SCALAR> in c.
-      bool __retrieveInputs( PRMClass<GUM_SCALAR>*                      c,
-                             const std::vector<std::string>&            chains,
-                             std::vector<PRMClassElement<GUM_SCALAR>*>& inputs );
+      bool __retrieveInputs(PRMClass< GUM_SCALAR >*                        c,
+                            const std::vector< std::string >&              chains,
+                            std::vector< PRMClassElement< GUM_SCALAR >* >& inputs);
 
       /// @brief Retrieve the common PRMType<GUM_SCALAR> of a vector of
       /// PRMClassElement<GUM_SCALAR>.
@@ -931,8 +969,8 @@ namespace gum {
       /// PRMClassElement<GUM_SCALAR> without a PRMType<GUM_SCALAR>.
       /// @throw NotFound Raised if there exists no common super type of all
       ///                 PRMClassElement<GUM_SCALAR> in elts.
-      PRMType<GUM_SCALAR>* __retrieveCommonType(
-          const std::vector<PRMClassElement<GUM_SCALAR>*>& elts );
+      PRMType< GUM_SCALAR >* __retrieveCommonType(
+        const std::vector< PRMClassElement< GUM_SCALAR >* >& elts);
 
       /// @brief Returns the inheritance depth of a PRMType<GUM_SCALAR>.
       ///
@@ -941,20 +979,20 @@ namespace gum {
       ///
       /// @param t The PRMType<GUM_SCALAR> for which we compute its depth.
       /// @return Returns the depth of t.
-      int __typeDepth( const PRMType<GUM_SCALAR>* t );
+      int __typeDepth(const PRMType< GUM_SCALAR >* t);
 
       /// Check if c implements correctly all his interfaces.
-      void __checkInterfaceImplementation( PRMClass<GUM_SCALAR>* c );
+      void __checkInterfaceImplementation(PRMClass< GUM_SCALAR >* c);
 
       /// Add a parent to an attribute.
-      void __addParent( PRMClassElementContainer<GUM_SCALAR>* c,
-                        PRMAttribute<GUM_SCALAR>*             agg,
-                        const std::string&                    name );
+      void __addParent(PRMClassElementContainer< GUM_SCALAR >* c,
+                       PRMAttribute< GUM_SCALAR >*             agg,
+                       const std::string&                      name);
 
       /// Add a parent to an aggregate.
-      void __addParent( PRMClass<GUM_SCALAR>*     c,
-                        PRMAggregate<GUM_SCALAR>* agg,
-                        const std::string&        name );
+      void __addParent(PRMClass< GUM_SCALAR >*     c,
+                       PRMAggregate< GUM_SCALAR >* agg,
+                       const std::string&          name);
       /// @}
       // ======================================================================
       ///  @name Private methods handling PRMSystem<GUM_SCALAR> and
@@ -963,23 +1001,23 @@ namespace gum {
       /// @{
 
       /// Adds a instance to the current model.
-      void __addInstance( PRMClass<GUM_SCALAR>* type, const std::string& name );
+      void __addInstance(PRMClass< GUM_SCALAR >* type, const std::string& name);
 
       /// Builds all PRMSlotChain<GUM_SCALAR><PRMInstance<GUM_SCALAR>> in the
       /// given
       /// model.
       /// @throw OperationNotAllowed If reference slots are left un affected
-      void __buildSlotChains( PRMSystem<GUM_SCALAR>* model );
+      void __buildSlotChains(PRMSystem< GUM_SCALAR >* model);
 
       /// Builds all Aggregates CPF in the given model.
       /// This must be called after all the slot chains have been generated.
-      void __buildAggregateCPF( PRMSystem<GUM_SCALAR>* model );
+      void __buildAggregateCPF(PRMSystem< GUM_SCALAR >* model);
 
       /// Instantiate a slot chain in the given instance
-      void __instantiateSlotChain( PRMSystem<GUM_SCALAR>*        model,
-                                   PRMInstance<GUM_SCALAR>*      inst,
-                                   PRMReferenceSlot<GUM_SCALAR>* ref,
-                                   PRMSlotChain<GUM_SCALAR>*     sc );
+      void __instantiateSlotChain(PRMSystem< GUM_SCALAR >*        model,
+                                  PRMInstance< GUM_SCALAR >*      inst,
+                                  PRMReferenceSlot< GUM_SCALAR >* ref,
+                                  PRMSlotChain< GUM_SCALAR >*     sc);
 
       /// Fill seq with the sequence of instance build using inst as the
       /// instantiation of sc->__class and seeking each instantiation of
@@ -987,9 +1025,9 @@ namespace gum {
       /// @return Returns the name of the corresponding
       /// PRMSlotChain<GUM_SCALAR>.
       std::string
-      __retrieveInstanceSequence( PRMInstance<GUM_SCALAR>*            inst,
-                                  Sequence<PRMInstance<GUM_SCALAR>*>& seq,
-                                  PRMSlotChain<GUM_SCALAR>*           sc );
+        __retrieveInstanceSequence(PRMInstance< GUM_SCALAR >*              inst,
+                                   Sequence< PRMInstance< GUM_SCALAR >* >& seq,
+                                   PRMSlotChain< GUM_SCALAR >*             sc);
 
       /// @}
       // ======================================================================
@@ -999,25 +1037,26 @@ namespace gum {
 
       /// The prefix used for classes and types names. It is normally the
       /// namespace of the corresponding compilation unit.
-      std::vector<std::string> __packages;
+      std::vector< std::string > __packages;
 
       /// Set of all declared namespaces.
-      std::vector<List<std::string>*> __namespaces;
+      std::vector< List< std::string >* > __namespaces;
 
       /// The pointer on the PRM<GUM_SCALAR> built by this factory.
-      PRM<GUM_SCALAR>* __prm;
+      PRM< GUM_SCALAR >* __prm;
 
       /// A stack used to keep track of created PRMObject.
-      std::vector<PRMObject*> __stack;
+      std::vector< PRMObject* > __stack;
 
       /// A mapping between aggregators and their parameters
-      HashTable<PRMAggregate<GUM_SCALAR>*, std::vector<std::string>> __agg_params;
+      HashTable< PRMAggregate< GUM_SCALAR >*, std::vector< std::string > >
+        __agg_params;
 
       /// @}
     };
   } /* namespace prm */
 } /* namespace gum */
 
-#include <agrum/PRM/PRMFactory.tcc>
+#include <agrum/PRM/PRMFactory_tpl.h>
 
 #endif /* GUM_PRM_FACTORY_H */
