@@ -27,10 +27,11 @@
 #ifndef GUM_RANDOM_VARIABLE_TYPE_H
 #define GUM_RANDOM_VARIABLE_TYPE_H
 
+#include <sstream>
 #include <vector>
 
-#include <agrum/multidim/multiDimArray.h>
-#include <agrum/multidim/multiDimImplementation.h>
+#include <agrum/multidim/implementations/multiDimArray.h>
+#include <agrum/multidim/implementations/multiDimImplementation.h>
 #include <agrum/variables/discreteVariable.h>
 #include <agrum/variables/labelizedVariable.h>
 
@@ -40,7 +41,7 @@
 namespace gum {
   namespace prm {
 
-    template <typename GUM_SCALAR>
+    template < typename GUM_SCALAR >
     class PRMFactory;
 
     /**
@@ -54,16 +55,15 @@ namespace gum {
      * Since MultiDim use pointers to handle DiscreteVariables, it is necessary
      * to create a new instance of a type for each PRMAttribute.
      */
-    template <typename GUM_SCALAR>
+    template < typename GUM_SCALAR >
     class PRMType : public PRMObject {
-
       public:
       // ==========================================================================
       /// @name Friends of PRMType
       // ==========================================================================
       /// @{
 
-      friend class PRMFactory<GUM_SCALAR>;
+      friend class PRMFactory< GUM_SCALAR >;
 
       /// @}
       // ==========================================================================
@@ -73,10 +73,10 @@ namespace gum {
 
       /// Returns a pointer on type boolean.
       static PRMType* boolean() {
-        LabelizedVariable var( "boolean", "Boolean variable", 0 );
-        var.addLabel( "false" );
-        var.addLabel( "true" );
-        return new PRMType( var );
+        LabelizedVariable var("boolean", "Boolean variable", 0);
+        var.addLabel("false");
+        var.addLabel("true");
+        return new PRMType(var);
       }
 
       /// @}
@@ -89,22 +89,22 @@ namespace gum {
        * Default Constructor.
        * A copy is made of var.
        */
-      PRMType( const DiscreteVariable& var );
+      explicit PRMType(const DiscreteVariable& var);
 
       /**
        * Sub type constructor.
        * A copy is made of var.
        * @throw OperationNotAllowed Raised if label_map is invalid.
        */
-      PRMType( PRMType&                super_type,
-               const std::vector<Idx>& label_map,
-               const DiscreteVariable& var );
+      PRMType(PRMType&                  super_type,
+              const std::vector< Idx >& label_map,
+              const DiscreteVariable&   var);
 
       /**
        * Copy constructor.
        * The DiscreteVariable is copied.
        */
-      PRMType( const PRMType& from );
+      PRMType(const PRMType& from);
 
       /**
        * Destructor.
@@ -152,12 +152,12 @@ namespace gum {
       /**
        * Equality operator.
        */
-      bool operator==( const PRMObject& from ) const;
+      bool operator==(const PRMObject& from) const;
 
       /**
        * Difference operator.
        */
-      bool operator!=( const PRMObject& from ) const;
+      bool operator!=(const PRMObject& from) const;
 
       /// @}
       // ==========================================================================
@@ -185,12 +185,12 @@ namespace gum {
        * Note that two types that are equal are also subtypes,
        * if a == b then a.isSubTypeOf(b) == b.isSubTypeOf(a) == true.
        */
-      bool isSubTypeOf( const PRMType& super ) const;
+      bool isSubTypeOf(const PRMType& super) const;
 
       /**
        * Returns true if this is a super type of t.
        */
-      bool isSuperTypeOf( const PRMType& t ) const;
+      bool isSuperTypeOf(const PRMType& t) const;
 
       /**
        * Returns the super type of this type.
@@ -221,14 +221,14 @@ namespace gum {
        * @throw OperationNotAllowed If this PRMType has no super.
        * @throw TypeError If t is not equal to this PRMType super.
        */
-      void setSuper( PRMType& t );
+      void setSuper(PRMType& t);
 
       /**
        * Returns the vector in which the i-th element is the Idx of the super
        * type's label for the i-th label of this.
        * @throw NotFound Raised if this type has no super type.
        */
-      const std::vector<Idx>& label_map() const;
+      const std::vector< Idx >& label_map() const;
 
       /// @}
       // ==========================================================================
@@ -238,10 +238,21 @@ namespace gum {
       // ==========================================================================
       /// @{
 
+      /**
+       * Move constructor.
+       * Not implemented, will raise an exception.
+       */
+      PRMType(PRMType&& from);
+
       /**
        * Copy operator. Not implemented.
        */
-      PRMType& operator=( const PRMType& from );
+      PRMType& operator=(const PRMType& from);
+
+      /**
+       * Move operator. Not implemented.
+       */
+      PRMType& operator=(PRMType&& from);
 
       /// @}
       // ==========================================================================
@@ -252,6 +263,10 @@ namespace gum {
       /// Returns true if this is a valid type or subtype.
       bool __isValid() const;
 
+      /// Used at construction to set a unique name to this class underlying
+      /// DiscreteVariable.
+      void __updateName();
+
       /// The discrete variable
       DiscreteVariable* __var;
 
@@ -260,19 +275,23 @@ namespace gum {
 
       /// A vector in which the i-th element is the Idx of the super
       /// type's label for the i-th label of this.
-      std::vector<Idx>* __label_map;
+      std::vector< Idx >* __label_map;
 
       /// @}
     };
 
 
-    extern template class PRMType<float>;
-    extern template class PRMType<double>;
+    extern template class PRMType< float >;
+    extern template class PRMType< double >;
 
 
   } /* namespace prm */
+#ifdef __clang__
+  extern template class HashFuncMediumCastKey< gum::prm::PRMType< float >* >;
+  extern template class HashFuncMediumCastKey< gum::prm::PRMType< double >* >;
+#endif
 } /* namespace gum */
 
-#include <agrum/PRM/elements/PRMType.tcc>
+#include <agrum/PRM/elements/PRMType_tpl.h>
 
 #endif /* GUM_CLASS_H */
