@@ -29,7 +29,7 @@
 #include <iostream>
 #include <string>
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 
 #include <agrum/core/bijection.h>
 #include <agrum/graphs/graphElements.h>
@@ -55,13 +55,13 @@ namespace gum {
 
     /// Copy constructor
     /// Proceed a deep copy: all variables are copied but keep the same node id.
-    VariableNodeMap( const VariableNodeMap& source );
+    VariableNodeMap(const VariableNodeMap& source);
 
     /// Destructor
     ~VariableNodeMap();
 
     /// Copy operator.
-    VariableNodeMap& operator=( const VariableNodeMap& source );
+    VariableNodeMap& operator=(const VariableNodeMap& source);
 
     /// @}
 
@@ -72,17 +72,17 @@ namespace gum {
 
     /// Returns a discrete variable given it's node id.
     /** @throws NotFound Raised if no nodes matches id. */
-    const DiscreteVariable& get( NodeId id ) const;
+    const DiscreteVariable& get(NodeId id) const;
 
     /// Returns a node id given it's variable.
     /** @throws NotFound Raised if no nodes matches var. */
-    NodeId get( const DiscreteVariable& var ) const;
+    NodeId get(const DiscreteVariable& var) const;
 
     /// Return true if id matches a node.
-    bool exists( NodeId id ) const;
+    bool exists(NodeId id) const;
 
     /// Return true if var matches a node.
-    bool exists( const DiscreteVariable& var ) const;
+    bool exists(const DiscreteVariable& var) const;
 
     /// Maps id with var.
     /**
@@ -90,20 +90,20 @@ namespace gum {
      * @throws DuplicateLabel if this name already exists
      * @throws DuplicateElement if this id already exists
      * @return Returns id (useful in some case); */
-    NodeId insert( NodeId id, const DiscreteVariable& var );
+    NodeId insert(NodeId id, const DiscreteVariable& var);
 
     /// Removes a var and it's id of this mapping. The pointer is deleted.
     /** @throws NotFound Raised if no nodes matches id. */
-    void erase( NodeId id );
+    void erase(NodeId id);
 
     /// Removes a var and it's id of this mapping. The pointer is deleted.
     /** @throws NotFound Raised if no nodes matches id. */
-    void erase( const DiscreteVariable& var );
+    void erase(const DiscreteVariable& var);
 
     /// we allow the user to change the name of a variable
     /** @throws DuplicateLabel if this name already exists
      * @throws NotFound Raised if no nodes matches id. */
-    void changeName( NodeId id, const std::string& new_name );
+    void changeName(NodeId id, const std::string& new_name);
 
     /// removes all the associations
     void clear();
@@ -117,7 +117,7 @@ namespace gum {
      * @return id's name.
      * @throw NotFound Raised if no variable matches id.
      */
-    const std::string& name( NodeId id ) const;
+    const std::string& name(NodeId id) const;
 
     /**
      * Returns the name of a variable.
@@ -125,7 +125,7 @@ namespace gum {
      * @return var's name.
      * @throw NotFound Raised if var is not in this VariableNodeMap.
      */
-    const std::string& name( const DiscreteVariable& var ) const;
+    const std::string& name(const DiscreteVariable& var) const;
 
     /// @}
 
@@ -136,11 +136,11 @@ namespace gum {
 
     /// Returns a discrete variable given it's node id.
     /** @throws NotFound Raised if no nodes matches id. */
-    const DiscreteVariable& operator[]( NodeId id ) const;
+    const DiscreteVariable& operator[](NodeId id) const;
 
     /// Returns a node id given it's variable.
     /** @throws NotFound Raised if no nodes matches var. */
-    NodeId operator[]( const DiscreteVariable& var ) const;
+    NodeId operator[](const DiscreteVariable& var) const;
 
     /// @}
 
@@ -150,30 +150,30 @@ namespace gum {
     /// @{
 
     /// @throw NotFound if no such name exists in the graph.
-    NodeId idFromName( const std::string& name ) const;
-    const DiscreteVariable& variableFromName( const std::string& name ) const;
+    NodeId                  idFromName(const std::string& name) const;
+    const DiscreteVariable& variableFromName(const std::string& name) const;
 
     /// @}
 
     private:
     /// effectively do the copy (for copy constructor or operator=)
-    void __copy( const VariableNodeMap& source );
+    void __copy(const VariableNodeMap& source);
 
     /// Bijection between the node's NodeIds and the variables.
-    Bijection<NodeId, const DiscreteVariable*> __nodes2vars;
+    Bijection< NodeId, const DiscreteVariable* > __nodes2vars;
 
     /// HashTable for easely find an id from a name
-    Bijection<std::string, NodeId> __names2nodes;
+    Bijection< std::string, NodeId > __names2nodes;
   };
 
   /// for friendly displaying the content of clique graphs
 
-  std::ostream& operator<<( std::ostream&, const VariableNodeMap& );
+  std::ostream& operator<<(std::ostream&, const VariableNodeMap&);
 
 } /* namespace gum */
 
 #ifndef GUM_NO_INLINE
-#include <agrum/graphicalModels/variableNodeMap_inl.h>
+#  include <agrum/graphicalModels/variableNodeMap_inl.h>
 #endif /* GUM_NO_INLINE */
 
 #endif /* GUM_VARIABLE_NODE_MAP_H*/
