@@ -52,10 +52,10 @@ namespace gum {
       K2();
 
       /// copy constructor
-      K2( const K2& from );
+      K2(const K2& from);
 
       /// move constructor
-      K2( K2&& from );
+      K2(K2&& from);
 
       /// destructor
       ~K2();
@@ -68,10 +68,10 @@ namespace gum {
       /// @{
 
       /// copy operator
-      K2& operator=( const K2& from );
+      K2& operator=(const K2& from);
 
       /// move operator
-      K2& operator=( K2&& from );
+      K2& operator=(K2&& from);
 
       /// @}
 
@@ -84,13 +84,13 @@ namespace gum {
       ApproximationScheme& approximationScheme();
 
       /// sets the order on the variables
-      void setOrder( const Sequence<NodeId>& order );
+      void setOrder(const Sequence< NodeId >& order);
 
       /// sets the order on the variables
-      void setOrder( const std::vector<NodeId>& order );
+      void setOrder(const std::vector< NodeId >& order);
 
       /// returns the current order
-      const Sequence<NodeId>& order() const noexcept;
+      const Sequence< NodeId >& order() const noexcept;
 
       /// learns the structure of a Bayes net
       /**
@@ -101,31 +101,31 @@ namespace gum {
        * @param modal the domain sizes of the random variables observed in the
        * database
        * @param initial_dag the DAG we start from for our learning */
-      template <typename GRAPH_CHANGES_SELECTOR>
-      DAG learnStructure( GRAPH_CHANGES_SELECTOR&  selector,
-                          const std::vector<Size>& modal,
-                          DAG                      initial_dag = DAG() );
+      template < typename GRAPH_CHANGES_SELECTOR >
+      DAG learnStructure(GRAPH_CHANGES_SELECTOR&    selector,
+                         const std::vector< Size >& modal,
+                         DAG                        initial_dag = DAG());
 
       /// learns the structure and the parameters of a BN
-      template <typename GUM_SCALAR,
-                typename GRAPH_CHANGES_SELECTOR,
-                typename PARAM_ESTIMATOR,
-                typename CELL_TRANSLATORS>
-      BayesNet<GUM_SCALAR> learnBN( GRAPH_CHANGES_SELECTOR&         selector,
-                                    PARAM_ESTIMATOR&                estimator,
-                                    const std::vector<std::string>& names,
-                                    const std::vector<Size>&        modal,
-                                    const CELL_TRANSLATORS&         translator,
-                                    DAG initial_dag = DAG() );
+      template < typename GUM_SCALAR,
+                 typename GRAPH_CHANGES_SELECTOR,
+                 typename PARAM_ESTIMATOR,
+                 typename CELL_TRANSLATORS >
+      BayesNet< GUM_SCALAR > learnBN(GRAPH_CHANGES_SELECTOR&           selector,
+                                     PARAM_ESTIMATOR&                  estimator,
+                                     const std::vector< std::string >& names,
+                                     const std::vector< Size >&        modal,
+                                     const CELL_TRANSLATORS&           translator,
+                                     DAG initial_dag = DAG());
 
       private:
       /// the order on the variable used for learning
-      Sequence<NodeId> __order;
+      Sequence< NodeId > __order;
 
       /** @brief checks that the order passed to K2 is coherent with the
        * variables
        * as specified by their modalities */
-      void __checkOrder( const std::vector<Size>& modal );
+      void __checkOrder(const std::vector< Size >& modal);
       /// @}
     };
 
@@ -135,10 +135,10 @@ namespace gum {
 
 /// include the inlined functions if necessary
 #ifndef GUM_NO_INLINE
-#include <agrum/learning/K2.inl>
+#  include <agrum/learning/K2_inl.h>
 #endif /* GUM_NO_INLINE */
 
 /// always include templated methods
-#include <agrum/learning/K2.tcc>
+#include <agrum/learning/K2_tpl.h>
 
 #endif /* GUM_LEARNING_K2_H */
