@@ -31,15 +31,17 @@
 #include <iostream>
 #include <string>
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 
 namespace gum {
 
+  enum class VarType : char { Discretized, Labelized, Range, Continuous };
+
   class Variable;
 
   /// for friendly displaying the content of the variable
 
-  std::ostream& operator<<( std::ostream& s, const Variable& LDRV );
+  std::ostream& operator<<(std::ostream& s, const Variable& LDRV);
 
   /* ===========================================================================
    */
@@ -85,15 +87,15 @@ namespace gum {
     /** @param aRV to be copied
      * @return a const ref to *this */
 
-    Variable& operator=( const Variable& aRV );
+    Variable& operator=(const Variable& aRV);
 
     /// equality operator
 
-    virtual bool operator==( const Variable& aRV ) const;
+    virtual bool operator==(const Variable& aRV) const;
 
     /// inequality operator
 
-    virtual bool operator!=( const Variable& aRV ) const;
+    virtual bool operator!=(const Variable& aRV) const;
 
     /// @}
 
@@ -105,7 +107,7 @@ namespace gum {
     /// sets the name of the variable
     /** @param theValue */
 
-    void setName( const std::string& theValue );
+    void setName(const std::string& theValue);
 
     /// returns the name of the variable
 
@@ -115,33 +117,38 @@ namespace gum {
     /// @warning since __description is mutable, setDescription() is const
     /** @param theValue */
 
-    void setDescription( const std::string& theValue ) const;
+    void setDescription(const std::string& theValue) const;
 
     /// returns the description of the variable
 
     const std::string& description() const;
 
+    /// returns the type of variable
+
+    virtual VarType varType() const = 0;
+
+
     /// @}
 
     protected:
     /// (protected) Default constructor
-    Variable() { GUM_CONSTRUCTOR( Variable ); };
+    Variable() { GUM_CONSTRUCTOR(Variable); };
 
     /// protected copy
     /** @param aRV to be copied */
 
-    void _copy( const Variable& aRV );
+    void _copy(const Variable& aRV);
 
     /// constructor
     /** @param aName name of the variable
      * @param aDesc description of the variable */
 
-    Variable( const std::string& aName, const std::string& aDesc );
+    Variable(const std::string& aName, const std::string& aDesc);
 
     /// copy constructor
     /** @param aRV the variable we copy */
 
-    Variable( const Variable& aRV );
+    Variable(const Variable& aRV);
 
     private:
     /// the name of the variable
@@ -156,7 +163,7 @@ namespace gum {
 } /* namespace gum */
 
 #ifndef GUM_NO_INLINE
-#include <agrum/variables/variable_inl.h>
+#  include <agrum/variables/variable_inl.h>
 #endif /* GUM_NO_INLINE */
 
 #endif /* GUM_VARIABLE_H */
