@@ -3,12 +3,12 @@
 Helping functions and consts for pyAgrum
 """
 
-#aGrum Licence( GPL )
+#aGrum Licence(GPL)
 #-- -- -- -- -- -- -- -- -- -
 #* This program is free software; you can redistribute it and / or modify *
 #* it under the terms of the GNU General Public License as published by *
 #* the Free Software Foundation; either version 2 of the License, or *
-#*( at your option ) any later version.*
+#*(at your option) any later version.*
 #* *
 #* This program is distributed in the hope that it will be useful, *
 #* but WITHOUT ANY WARRANTY; without even the implied warranty of *
@@ -24,13 +24,15 @@ from .pyAgrum import BayesNet
 from .pyAgrum import Potential
 from .pyAgrum import InfluenceDiagram
 from .pyAgrum import VariableElimination
+from .pyAgrum import BNDatabaseGenerator
+from .pyAgrum import PythonDatabaseGeneratorListener
 
 def about():
   """
   about() for pyAgrum
 
   """
-  print("pyAgrum version {0}".format('0.12.1'))
+  print("pyAgrum version {0}".format('0.13.2'))
   print("(c) Pierre-Henri Wuillemin, Christophe Gonzales, Lionel Torti")
   print("    UPMC 2015")
   print("""
@@ -49,11 +51,15 @@ def availableWriteBNExts():
     """
     :return: a string which lists all suffixes for supported output BN file formats.
     """
-    return "bif|dsl|net|bifxml|uai"
+    return "bif|dsl|net|bifxml|o3prm|uai"
 
-def loadBN(filename,listeners=None,verbose=True,**opts):
+def loadBN(filename,listeners=None,verbose=False,**opts):
     """
-    :param filename: the name of file
+    :param filename: the name of the input file
+    :param listeners: list of functions to execute
+    :param verbose: whether to print or not warning messages
+    :param system: (for O3PRM) name of the system to flatten in a BN
+    :param classpath: (for O3PRM) list of folders containing classes
     :return: a BN from a file using one of the availableBNExts() suffixes.
     """
     bn=BayesNet()
@@ -68,7 +74,7 @@ def loadBN(filename,listeners=None,verbose=True,**opts):
     elif extension=="NET":
         warns=bn.loadNET(filename,listeners)
     elif extension=="O3PRM":
-        warns=bn.loadPRM(filename,opts.get('system',''),opts.get('classpath',''),listeners)
+        warns=bn.loadO3PRM(filename,opts.get('system',''),opts.get('classpath',''),listeners)
     elif extension=="UAI":
         warns=bn.loadUAI(filename,listeners)
     else:
@@ -95,6 +101,8 @@ def saveBN(bn,filename):
         bn.saveNET(filename)
     elif extension=="UAI":
         bn.saveUAI(filename)
+    elif extension=="O3PRM":
+        bn.saveO3PRM(filename)
     else:
         raise Exception("extension "+filename.split('.')[-1]+" unknown. Please use "+availableWriteBNExts())
 
@@ -104,7 +112,7 @@ def loadID(filename):
   """
   read a gum.InfluenceDiagram from a bifxml file
 
-  :param filename: the name of file
+  :param filename: the name of the input file
   :return: an InfluenceDiagram
   """
 
@@ -127,9 +135,9 @@ def fastBN(arcs,domain_size=2):
   rapid prototyping of BN.
 
   :param arcs: dot-like simple list of arcs ("a->b->c;a->c->d" for instance). The first apparition of a node name can be
-   enhanced with a "[domain_size]" extension. For instance "a[5]->b->c;a[2]->c->d" will create a bn with a variable "a"
-   with a.nbrDim()==5 (the second "a[2]" is not taken into accound since the variable is already created).
-  :param domain_size: number of modalities for each created variable.
+   enhanced with a "[domain_size]" extension. For instance "a[5]->b->c;a[2]->c->d" will create a BN with a variable "a"
+   whos domain size is a.nbrDim()==5 (the second "a[2]" is not taken into account since the variable has already been created).
+  :param domain_size: the domain size of each created variable.
   :return: the created pyAgrum.BayesNet
   """
   return BayesNet.fastPrototype(arcs,domain_size)
@@ -155,5 +163,52 @@ def getPosterior(bn, evs, target):
   inf.setEvidence(evs)
   inf.addTarget(target)
   inf.makeInference()
+#creating a new Potential from posterior(will disappear with ie)
   return Potential(inf.posterior(target))
-#creating a new Potential from posterior( will disappear with ie )
+
+
+def generateCSV(bn, name_out, n, visible=False, with_labels=False):
+  """
+  generate a CSV file of samples from a bn.
+
+  :param bn: the BN from which the sample is generated
+  :type bn: pyAgrum.BayesNet
+  :param name_out: the name for the output filename
+  :type name_out: string
+  :param n: the number of samples
+  :type n: int
+  :param visible: if True, show a progress bar
+  :type visible: boolean
+  :param with_labels: if True, use the labels of the modalities of variables in the csv. If False, use their ids.
+  :type with_labels: boolean
+  :return: the log2-likelihood of the generated base
+  """
+
+  genere = BNDatabaseGenerator(bn)
+  if visible:
+    from pyAgrum.lib._utils.progress_bar import ProgressBar
+    prog = ProgressBar(name_out + ' : ', 0, 100, 77, mode='static', char='#')
+    prog.display()
+    listen = PythonDatabaseGeneratorListener(genere)
+
+    def whenStep(x, y):
+      prog.increment_amount()
+      prog.display()
+
+    def whenStop(msg):
+      prog.update_amount(100)
+      prog.display()
+      print()
+
+    listen.setWhenProgress(whenStep)
+    listen.setWhenStop(whenStop)
+
+  genere.setRandomVarOrder()
+  ll=genere.drawSamples(n)
+
+  genere.toCSV(name_out,with_labels)
+
+  if visible:
+    print("Log2-Likelihood : {}".format(ll))
+
+  return ll
